%define major		3
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define build_python	1

Summary:	Lowlevel DNS(SEC) library with API
Name:		ldns
Version:	1.8.4
Release:	%mkrel 2
License:	BSD
Group:		System/Libraries
URL:		https://www.nlnetlabs.nl/ldns/
Source0:	https://www.nlnetlabs.nl/downloads/ldns/ldns-%{version}.tar.gz

BuildRequires:	pkgconfig(libpcap)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	doxygen
%if %{build_python}
BuildRequires:	swig
BuildRequires:	pkgconfig(python3)
%endif

%description
ldns is a library with the aim to simplify DNS programming in C. All
lowlevel DNS/DNSSEC operations are supported. We also define a higher
level API which allows a programmer to (for instance) create or sign
packets.

%package -n	%{name}-utils
Summary:	DNS(SEC) utility
Group:		Networking/Other

%description -n	%{name}-utils
This package contains various utilities used to manage
and validate DNSSEC zones using ldns library.

%package -n	%{libname}
Summary:	Lowlevel DNS(SEC) library with API
Group:		System/Libraries

%description -n	%{libname}
ldns is a library with the aim to simplify DNS programming in C. All
lowlevel DNS/DNSSEC operations are supported. We also define a higher
level API which allows a programmer to (for instance) create or sign
packets.

%package -n	%{develname}
Summary:	Development package that includes the ldns header files
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The devel package contains the ldns library and the include files.

%if %{build_python}
%package -n 	python3-%{name}
Summary:	Python 3 extensions for ldns
Group:		Development/Python
Provides:	python3dist(ldns)= %{version}
Provides:	python%{python3_version}dist(ldns)

Obsoletes:	python-ldns < 1.7.0-4
Provides:	python-ldns = %{version}-%{release}

%description -n python3-%{name}
Python 3 extensions for ldns.
%endif

%prep
%autosetup -p2

# Fix build with SWIG 4.3
sed -i -e 's/SWIG_Python_AppendOutput/SWIG_AppendOutput/' $(grep -rl SWIG_Python_AppendOutput)

%build
export PYTHON=%{python3}
%configure \
    --disable-rpath \
%if %{build_python}
    --with-pyldns \
%endif
    --with-examples \
    --with-drill \
    --disable-gost \
    --disable-static

%make_build

%install
mkdir -p %{buildroot}%{_libdir}/pkgconfig
%make_install

# cleanup and fix --short-circuit
rm -rf docs; mkdir -p docs
cp -rp doc docs/
rm -rf docs/doc/man
rm -f docs/doc/doxyparse.pl
rm -f docs/doc/ldns_manpages
rm -rf docs/doc/.svn

#we don't want these
find %{buildroot} -name "*.la" -delete

%if %{build_python}
#remove executable bit
chmod a-x %{buildroot}%{python3_sitearch}/*py
%endif

%files -n %{libname}
%doc README
%license LICENSE
%{_libdir}/lib*so.%{major}{,.*}

%files -n %{develname}
%doc docs/* Changelog README
%dir %{_includedir}/ldns
%{_includedir}/ldns/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*
%{_bindir}/%{name}-config

%files -n %{name}-utils
%{_bindir}/*
%exclude %{_bindir}/%{name}-config
%{_mandir}/man1/*

%if %{build_python}
%files -n python3-%{name}
%{python3_sitearch}/*
%endif


%changelog
* Tue Dec 24 2024 wally <wally> 1.8.4-2.mga10
+ Revision: 2129801
- fix build with SWIG >= 4.3.0

* Mon Oct 21 2024 papoteur <papoteur> 1.8.4-1.mga10
+ Revision: 2109180
- new version 1.8.4
+ daviddavid <daviddavid>
- SWIG 4.2 and i686 compatibility

* Tue Dec 19 2023 papoteur <papoteur> 1.8.3-2.mga10
+ Revision: 2019511
- Mass Rebuild - Python 3.12

* Mon Oct 03 2022 neoclust <neoclust> 1.8.3-1.mga9
+ Revision: 1894495
- New version

* Tue Mar 29 2022 umeabot <umeabot> 1.8.1-2.mga9
+ Revision: 1831293
- Mageia 9 Mass Rebuild

* Fri Dec 17 2021 neoclust <neoclust> 1.8.1-1.mga9
+ Revision: 1762389
- New version 1.8.1 (mga#29776)
+ wally <wally>
- rebuild for openssl 3.0.0

* Fri Mar 26 2021 daviddavid <daviddavid> 1.7.1-3.mga9
+ Revision: 1710336
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 1.7.1-2.mga8
+ Revision: 1535013
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 08 2019 daviddavid <daviddavid> 1.7.1-1.mga8
+ Revision: 1450581
- new version: 1.7.1
- now libmajor is 3
- port to python 3

* Sun Sep 23 2018 umeabot <umeabot> 1.7.0-3.mga7
+ Revision: 1298728
- Mageia 7 Mass Rebuild

* Wed Nov 22 2017 guillomovitch <guillomovitch> 1.7.0-2.mga7
+ Revision: 1178891
- fix two memory corruption issues, using upstream patches
- fix two memory corruption issues, using upstream patches

* Fri Sep 15 2017 guillomovitch <guillomovitch> 1.7.0-1.mga7
+ Revision: 1154111
- new version 1.7.0

* Wed Mar 02 2016 umeabot <umeabot> 1.6.17-8.mga6
+ Revision: 983560
- Rebuild for openssl
- Mageia 6 Mass Rebuild

* Thu Nov 12 2015 tv <tv> 1.6.17-6.mga6
+ Revision: 902909
- fix build

* Wed Oct 15 2014 umeabot <umeabot> 1.6.17-5.mga5
+ Revision: 748352
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.6.17-4.mga5
+ Revision: 726691
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.6.17-3.mga5
+ Revision: 681291
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.6.17-2.mga5
+ Revision: 628287
- Rebuild for new Python

* Wed May 07 2014 oden <oden> 1.6.17-1.mga5
+ Revision: 621008
- 1.6.17
- P0: rediff
- P1: rediff
- P2: security fix for CVE-2014-3209 (upstream)

* Fri Oct 18 2013 umeabot <umeabot> 1.6.16-3.mga4
+ Revision: 506890
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.6.16-2.mga3
+ Revision: 356745
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 dlucio <dlucio> 1.6.16-1.mga3
+ Revision: 323663
- 1.6.16
- P0 rediffed

* Sun Mar 25 2012 dlucio <dlucio> 1.6.12-1.mga2
+ Revision: 226298
- SPEC fixes
- imported package ldns


* Wed Jan 11 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.6.12-1
+ Revision: 760141
- version update 1.6.12

* Sat Nov 05 2011 Oden Eriksson <oeriksson@mandriva.com> 1.6.11-2
+ Revision: 719584
- bump release
- fix build
- 1.6.11 (fixes CVE-2011-3581)

* Sun Jun 12 2011 Oden Eriksson <oeriksson@mandriva.com> 1.6.10-1
+ Revision: 684325
- 1.6.10

* Wed Jun 01 2011 Oden Eriksson <oeriksson@mandriva.com> 1.6.9-1
+ Revision: 682253
- 1.6.9

* Wed Mar 16 2011 Stéphane Téletchéa <steletch@mandriva.org> 1.6.8-1
+ Revision: 645249
- update to new version 1.6.8

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 1.6.6-3mdv2011.0
+ Revision: 590007
- rebuild for python 2.7

* Mon Oct 25 2010 Jani Välimaa <wally@mandriva.org> 1.6.6-2mdv2011.0
+ Revision: 589267
- add more conditionals for building python subpackage

* Mon Oct 25 2010 Jani Välimaa <wally@mandriva.org> 1.6.6-1mdv2011.0
+ Revision: 589266
- new version 1.6.6
- build python extensions
- minor spec cleaning
- disable static build

* Tue Oct 19 2010 Michael Scherer <misc@mandriva.org> 1.6.4-3mdv2011.0
+ Revision: 586687
- add a ldns-utils subpackage with various utilities

* Tue Apr 20 2010 Funda Wang <fwang@mandriva.org> 1.6.4-2mdv2010.1
+ Revision: 536962
- rebuild

* Tue Mar 02 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.6.4-1mdv2010.1
+ Revision: 513634
- update to 1.6.4

* Fri Jul 31 2009 Frederik Himpe <fhimpe@mandriva.org> 1.6.0-1mdv2010.0
+ Revision: 405233
- Update to new version 1.6.0

* Thu Mar 26 2009 Oden Eriksson <oeriksson@mandriva.com> 1.5.1-1mdv2009.1
+ Revision: 361325
- 1.5.1 (fixes CVE-2009-1086)

* Mon Dec 08 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-0.20081103.1mdv2009.1
+ Revision: 311881
- 1.4.0 (from unbound-1.1.1.tar.gz)

* Mon Dec 08 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.0-4mdv2009.1
+ Revision: 311861
- 1.3.0 (final)

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 1.3.0-3.20080229.2mdv2009.0
+ Revision: 267800
- rebuild early 2009.0 package (before pixel changes)

* Fri May 30 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.0-0.20080229.2mdv2009.0
+ Revision: 213295
- fix deps

* Thu May 29 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.0-0.20080229.1mdv2009.0
+ Revision: 213178
- import ldns

